module InfinumId
  module Api
    class WebhooksController < Api::BaseController
      def upsert_resource_callback
        intent, resource = upsert

        InfinumId::AfterResourceUpsert.call(resource, params[:user], intent)

        render json: { resource_name.underscore => 'updated' }
      end

      def update_resource_callback
        return head :not_found if resource.blank?

        intent, resource = update

        InfinumId::AfterResourceUpsert.call(resource, params[:user], intent)

        render json: { resource_name.underscore => 'updated' }
      end

      private

      def user_params
        params.require(:user)
              .permit(InfinumId.resource_attributes)
              .merge(provider: params[:provider])
      end

      def resource
        @resource ||=
          resource_class.find_by(uid: user_params[:uid], provider: params[:provider]) ||
          resource_class.find_by(email: user_params[:email])
      end

      def update
        resource.update(user_params)
        [InfinumId::AfterResourceIntent::UPDATE, resource]
      end

      def upsert
        if resource
          resource.update(user_params)
          [InfinumId::AfterResourceIntent::UPDATE, resource]
        else
          @resource = resource_class.create(user_params)

          [InfinumId::AfterResourceIntent::CREATE, resource]
        end
      end
    end
  end
end
